@@ -47,9 +47,11 @@
 #define TXT_EXT          "txt"
 #define WQL_EXT          "wql"
 
+/** @details Private Data class for KEduVocDocument */
 class KEduVocDocument::KEduVocDocumentPrivate
 {
 public:
+    /** constructor */
     KEduVocDocumentPrivate( KEduVocDocument* qq )
             : q( qq )
     {
@@ -60,11 +62,13 @@ public:
         init();
     }
 
+    /** destructor */
     ~KEduVocDocumentPrivate();
 
+    /** initializer */
     void init();
 
-    KEduVocDocument* q;
+    KEduVocDocument* q;                               ///< The Front End
 
     /** autosave file used to provide locking access to the underlying file
      * Note: It is a pointer to allow locking a new file, saving results and
@@ -72,36 +76,39 @@ public:
      * See saveAs for clarification*/
     KAutoSaveFile            *m_autosave;
 
-    bool                      m_dirty;
+    bool                      m_dirty;                ///<dirty bit
 
     // save these to document
-    QList<KEduVocIdentifier>  m_identifiers;
+    QList<KEduVocIdentifier>  m_identifiers;          ///<list of identifiers
 
-    QList<int>                m_extraSizeHints;
-    QList<int>                m_sizeHints;
+    QList<int>                m_extraSizeHints;       ///< unused
+    QList<int>                m_sizeHints;            ///< unused
 
-    QString                   m_generator;
-    QString                   m_queryorg;
-    QString                   m_querytrans;
+    QString                   m_generator;            ///< name of generating application
+    QString                   m_queryorg;             ///< unused
+    QString                   m_querytrans;           ///< unused
 
-    QStringList               m_tenseDescriptions;
-    QSet<QString>             m_usages;
+    QStringList               m_tenseDescriptions;    ///< unused. Was used in merge
+    QSet<QString>             m_usages;               ///< unused
 
-    QString                   m_title;
-    QString                   m_author;
-    QString                   m_authorContact;
-    QString                   m_license;
-    QString                   m_comment;
-    QString                   m_version;
-    QString                   m_csvDelimiter;
+    QString                   m_title;                ///< Document title
+    QString                   m_author;               ///< Document author
+    QString                   m_authorContact;        ///< Author contact information
+    QString                   m_license;              ///< Document license
+    QString                   m_comment;              ///< Document comment
+    QString                   m_version;              ///< Document version
+    QString                   m_csvDelimiter;         ///< CSV delimiter
 
     /** Categories that can later be used to sork kvtml files:
       * language, music, children, anatomy
       */
-    QString                   m_category;
+    QString                   m_category;            ///< Document category
 
-    KEduVocLesson * m_lessonContainer;
-    KEduVocWordType * m_wordTypeContainer;
+    KEduVocLesson * m_lessonContainer;               ///< Root lesson container
+    KEduVocWordType * m_wordTypeContainer;           ///< Root word types container
+    /** Root Leitner container
+     * (probably unused) This is not used in Parley
+     * */
     KEduVocLeitnerBox * m_leitnerContainer;
 
     /** Creates an autosave file for fpath in order to lock the file
@@ -202,76 +209,14 @@ void KEduVocDocument::setModified( bool dirty )
 KEduVocDocument::FileType KEduVocDocument::detectFileType( const QString &fileName )
 {
     QIODevice * f = KFilterDev::deviceForFile( fileName );
-    if ( !f->open( QIODevice::ReadOnly ) ) {
-        kDebug(1100) << "Warning, could not open QIODevice for file: " << fileName;
-        delete f;
-        return Csv;
-    }
+    f->open( QIODevice::ReadOnly );
 
-    QTextStream ts( f );
-    QString line1;
-    QString line2;
+    ReaderManager::ReaderPtr reader( ReaderManager::reader( *f ) );
 
-    line1 = ts.readLine();
-    if ( !ts.atEnd() ) {
-        line2 = ts.readLine();
-    }
-
-    /*
-     * Vokabeln.de files:
-    The header seems to be something like this:
-
-    "Name
-    Lang1 - Lang2",123,234,456
-    0
-
-    or something longer:
-
-    "Name
-    Lang1 - Lang2
-    [..]
-    Blah, blah, blah...",123,234,456
-    0
-    */
-
-    QString tmp;
-
-    if ( line1.startsWith(QChar::fromLatin1('"'))) {
-        ts.seek(0);
-        tmp = ts.readLine();
-        // There shouldn't be headers longer than 10 lines.
-        for ( int x=0; x < 10; x++) {
-            if (tmp.contains( "\"," )) {
-                tmp = ts.readLine();
-                if (tmp.endsWith('0')) {
-                    f->close();
-                    delete f;
-                    return Vokabeln;
-                }
-            }
-            tmp = ts.readLine();
-        }
-    }
     f->close();
     delete f;
 
-
-    if ( line1.startsWith(QString::fromLatin1("<?xml")) ) {
-        if ( line2.indexOf( "pauker", 0 ) >  0 ) {
-            return Pauker;
-        }
-        if ( line2.indexOf( "xdxf", 0 ) >  0 ) {
-            return Xdxf;
-        } else {
-            return Kvtml;
-        }
-    }
-
-    if ( line1 == WQL_IDENT ) {
-        return Wql;
-    }
-
-    return Csv;
+    return reader->fileTypeHandled();
 }
 
 
